@@ -5,9 +5,9 @@
 ;; Created: 2010
 ;; Keywords: languages
 ;; URL: https://github.com/openscad/emacs-scad-mode
-;; Package-Requires: ((emacs "28.1") (compat "30"))
-;; Package-Version: 20251007.1702
-;; Package-Revision: b130730a3123
+;; Package-Requires: ((emacs "29.1") (compat "30"))
+;; Package-Version: 20260104.1120
+;; Package-Revision: 23e4a92342f9
 
 ;; This file is not part of GNU Emacs.
 
@@ -198,7 +198,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
 
 (defun scad-completion-at-point ()
   "Completion at point function."
-  (when-let (bounds (bounds-of-thing-at-point 'word))
+  (when-let* ((bounds (bounds-of-thing-at-point 'word)))
     (list (car bounds) (cdr bounds)
           scad-completions
           :exclusive 'no)))
@@ -322,7 +322,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
           ;; Setting the OPENSCADPATH to the current directory allows openscad to pick
           ;; up other local files with `include <file.scad>'.
           (("OPENSCADPATH"
-            (if-let ((path (getenv "OPENSCADPATH")))
+            (if-let* ((path (getenv "OPENSCADPATH")))
                 (concat default-directory path-separator path)
               default-directory)))
         (setq scad--preview-proc
@@ -468,7 +468,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
         ;; Setting the OPENSCADPATH to the current directory allows openscad to pick
         ;; up other local files with `include <file.scad>'.
         (("OPENSCADPATH"
-          (if-let ((path (getenv "OPENSCADPATH")))
+          (if-let* ((path (getenv "OPENSCADPATH")))
               (concat default-directory path-separator path)
             default-directory)))
       (setq
